@@ -25,6 +25,16 @@
 
 static void aisleriot_card_paint (ClutterActor *actor);
 
+static void aisleriot_card_get_preferred_width (ClutterActor *self,
+                                                ClutterUnit   for_height,
+                                                ClutterUnit  *min_width_p,
+                                                ClutterUnit  *natural_width_p);
+static void aisleriot_card_get_preferred_height
+                                               (ClutterActor *self,
+                                                ClutterUnit   for_width,
+                                                ClutterUnit  *min_height_p,
+                                                ClutterUnit  *natural_height_p);
+
 static void aisleriot_card_dispose (GObject *self);
 
 static void aisleriot_card_set_property (GObject      *self,
@@ -56,7 +66,7 @@ G_DEFINE_TYPE (AisleriotCard, aisleriot_card, CLUTTER_TYPE_ACTOR);
 
 struct _AisleriotCardPrivate
 {
-  Card card;
+  Card bottom_card, top_card;
   ClutterColor highlight_color;
   gboolean highlighted;
 
@@ -68,7 +78,8 @@ enum
   PROP_0,
 
   PROP_CACHE,
-  PROP_CARD,
+  PROP_BOTTOM_CARD,
+  PROP_TOP_CARD,
   PROP_HIGHLIGHTED,
   PROP_HIGHLIGHT_COLOR
 };
@@ -101,15 +112,26 @@ aisleriot_card_class_init (AisleriotCardClass *klass)
   gobject_class->get_property = aisleriot_card_get_property;
 
   actor_class->paint = aisleriot_card_paint;
+  actor_class->get_preferred_width = aisleriot_card_get_preferred_width;
+  actor_class->get_preferred_height = aisleriot_card_get_preferred_height;
 
-  pspec = g_param_spec_uchar ("card", NULL, NULL,
+  pspec = g_param_spec_uchar ("bottom-card", NULL, NULL,
                               0, 255, 0,
                               G_PARAM_WRITABLE |
                               G_PARAM_READABLE |
                               G_PARAM_STATIC_NAME |
                               G_PARAM_STATIC_NICK |
                               G_PARAM_STATIC_BLURB);
-  g_object_class_install_property (gobject_class, PROP_CARD, pspec);
+  g_object_class_install_property (gobject_class, PROP_BOTTOM_CARD, pspec);
+
+  pspec = g_param_spec_uchar ("top-card", NULL, NULL,
+                              0, 255, 0,
+                              G_PARAM_WRITABLE |
+                              G_PARAM_READABLE |
+                              G_PARAM_STATIC_NAME |
+                              G_PARAM_STATIC_NICK |
+                              G_PARAM_STATIC_BLURB);
+  g_object_class_install_property (gobject_class, PROP_TOP_CARD, pspec);
 
   pspec = g_param_spec_object ("cache", NULL, NULL,
                                GAMES_TYPE_CARD_TEXTURES_CACHE,
@@ -176,16 +198,70 @@ aisleriot_card_dispose (GObject *self)
 
 ClutterActor *
 aisleriot_card_new (GamesCardTexturesCache *cache,
-                    Card card,
+                    Card bottom_card,
+                    Card top_card,
                     const ClutterColor *highlight_color)
 {
   return g_object_new (AISLERIOT_TYPE_CARD,
                        "cache", cache,
-                       "card", card.value,
+                       "bottom-card", bottom_card.value,
+                       "top-card", top_card.value,
                        "highlight-color", highlight_color,
                        NULL);
 }
 
+static void
+aisleriot_card_get_preferred_width (ClutterActor *self,
+                                    ClutterUnit   for_height,
+                                    ClutterUnit  *min_width_p,
+                                    ClutterUnit  *natural_width_p)
+{
+  AisleriotCard *card = AISLERIOT_CARD (self);
+  AisleriotCardPrivate *priv = card->priv;
+  CoglHandle tex;
+  guint width;
+
+  tex = games_card_textures_cache_get_card_texture (priv->cache,
+                                                    priv->top_card);
+
+  if (G_UNLIKELY (tex == COGL_INVALID_HANDLE))
+    width = 0;
+  else
+    width = cogl_texture_get_width (tex);
+
+  if (min_width_p)
+    *min_width_p = 0;
+
+  if (natural_width_p)
+    *natural_width_p = CLUTTER_UNITS_FROM_DEVICE (width);
+}
+
+static void
+aisleriot_card_get_preferred_height (ClutterActor *self,
+                                     ClutterUnit   for_width,
+                                     ClutterUnit  *min_height_p,
+                                     ClutterUnit  *natural_height_p)
+{
+  AisleriotCard *card = AISLERIOT_CARD (self);
+  AisleriotCardPrivate *priv = card->priv;
+  CoglHandle tex;
+  guint height;
+
+  tex = games_card_textures_cache_get_card_texture (priv->cache,
+                                                    priv->top_card);
+
+  if (G_UNLIKELY (tex == COGL_INVALID_HANDLE))
+    height = 0;
+  else
+    height = cogl_texture_get_height (tex);
+
+  if (min_height_p)
+    *min_height_p = 0;
+
+  if (natural_height_p)
+    *natural_height_p = CLUTTER_UNITS_FROM_DEVICE (height);
+}
+
 static void
 aisleriot_card_paint (ClutterActor *actor)
 {
@@ -194,15 +270,10 @@ aisleriot_card_paint (ClutterActor *actor)
   Card card_num;
   ClutterFixed x_angle, y_angle;
   CoglHandle tex;
-  ClutterFixed tex_width, tex_height;
+  ClutterActorBox alloc_box;
   gboolean x_swapped = FALSE;
   static const ClutterColor white = { 0xff, 0xff, 0xff, 0xff };
-
-  card_num = priv->card;
-
-  tex = games_card_textures_cache_get_card_texture (priv->cache, card_num);
-  if (G_UNLIKELY (tex == COGL_INVALID_HANDLE))
-    return;
+  gboolean show_top = TRUE;
 
   x_angle = clutter_actor_get_rotationx (actor, CLUTTER_X_AXIS,
                                          NULL, NULL, NULL);
@@ -212,36 +283,43 @@ aisleriot_card_paint (ClutterActor *actor)
   /* Show the other side of the card if it is rotated more than 180
      degrees in exactly one of the axes */
   if (ANGLE_IS_UPSIDE_DOWN (x_angle))
-    card_num.attr.face_down = !card_num.attr.face_down;
+    show_top = !show_top;
   if (ANGLE_IS_UPSIDE_DOWN (y_angle)) {
-    card_num.attr.face_down = !card_num.attr.face_down;
-    /* The picture for the back of the card is already drawn as if it
-       was rotated so we need to swap the coordinates so it will look
-       right when it is rotated again */
-    if (card_num.attr.face_down)
-      x_swapped = TRUE;
+    show_top = !show_top;
+    x_swapped = TRUE;
   }
 
-  tex_width = CLUTTER_INT_TO_FIXED (cogl_texture_get_width (tex));
-  tex_height = CLUTTER_INT_TO_FIXED (cogl_texture_get_height (tex));
+  card_num = show_top ? priv->top_card : priv->bottom_card;
+
+  tex = games_card_textures_cache_get_card_texture (priv->cache, card_num);
+  if (G_UNLIKELY (tex == COGL_INVALID_HANDLE))
+    return;
+
+  clutter_actor_get_allocation_box (actor, &alloc_box);
 
   /* Ideally we would just swap the texture coordinates, but Cogl
      won't let you do this */
   if (x_swapped) {
     cogl_push_matrix ();
-    cogl_translate (CLUTTER_FIXED_TO_INT (tex_width) / 2, 0, 0);
+    cogl_translate (CLUTTER_UNITS_TO_DEVICE (alloc_box.x2 - alloc_box.x1) / 2,
+                    0, 0);
     cogl_rotate (180, 0, 1, 0);
-    cogl_translate (-CLUTTER_FIXED_TO_INT (tex_width) / 2, 0, 0);
+    cogl_translate (-CLUTTER_UNITS_TO_DEVICE (alloc_box.x2 - alloc_box.x1) / 2,
+                    0, 0);
   }
 
   cogl_color (&white);
   cogl_texture_rectangle (tex, 0, 0,
-                          tex_width, tex_height,
+                          CLUTTER_UNITS_TO_FIXED (alloc_box.x2 - alloc_box.x1),
+                          CLUTTER_UNITS_TO_FIXED (alloc_box.y2 - alloc_box.y1),
                           0, 0, CFX_ONE, CFX_ONE);
   if (priv->highlighted) {
     cogl_color (&priv->highlight_color);
     cogl_texture_rectangle (tex, 0, 0,
-                            tex_width, tex_height,
+                            CLUTTER_UNITS_TO_FIXED (alloc_box.x2
+                                                    - alloc_box.x1),
+                            CLUTTER_UNITS_TO_FIXED (alloc_box.y2
+                                                    - alloc_box.y1),
                             0, 0, CFX_ONE, CFX_ONE);
   }
 
@@ -258,13 +336,23 @@ aisleriot_card_set_property (GObject *self,
   AisleriotCard *card = AISLERIOT_CARD (self);
 
   switch (property_id) {
-    case PROP_CARD:
+    case PROP_BOTTOM_CARD:
       {
         Card card_num;
 
         card_num.value = g_value_get_uchar (value);
 
-        aisleriot_card_set_card (card, card_num);
+        aisleriot_card_set_card (card, card_num, card->priv->top_card);
+      }
+      break;
+
+    case PROP_TOP_CARD:
+      {
+        Card card_num;
+
+        card_num.value = g_value_get_uchar (value);
+
+        aisleriot_card_set_card (card, card->priv->bottom_card, card_num);
       }
       break;
 
@@ -296,8 +384,12 @@ aisleriot_card_get_property (GObject *self,
   AisleriotCardPrivate *priv = card->priv;
 
   switch (property_id) {
-    case PROP_CARD:
-      g_value_set_uchar (value, priv->card.value);
+    case PROP_BOTTOM_CARD:
+      g_value_set_uchar (value, priv->bottom_card.value);
+      break;
+
+    case PROP_TOP_CARD:
+      g_value_set_uchar (value, priv->top_card.value);
       break;
 
     case PROP_CACHE:
@@ -316,7 +408,9 @@ aisleriot_card_get_property (GObject *self,
 }
 
 void
-aisleriot_card_set_card (AisleriotCard *card, Card card_num)
+aisleriot_card_set_card (AisleriotCard *card,
+                         Card bottom_card,
+                         Card top_card)
 {
   AisleriotCardPrivate *priv;
 
@@ -324,11 +418,13 @@ aisleriot_card_set_card (AisleriotCard *card, Card card_num)
 
   priv = card->priv;
 
-  priv->card = card_num;
+  priv->bottom_card = bottom_card;
+  priv->top_card = top_card;
 
   clutter_actor_queue_redraw (CLUTTER_ACTOR (card));
 
-  g_object_notify (G_OBJECT (card), "card");
+  g_object_notify (G_OBJECT (card), "bottom-card");
+  g_object_notify (G_OBJECT (card), "top-card");
 }
 
 static void
